@@ -1,5 +1,9 @@
-use compact_genome::implementation::ascii_vec_sequence_store::{AsciiVectorSequenceStore, AsciiVectorSequenceStoreHandle};
-use compact_genome::implementation::two_bit_vec_sequence_store::{TwoBitVectorSequenceStore, TwoBitVectorSequenceStoreHandle};
+use compact_genome::implementation::ascii_vec_sequence_store::{
+    AsciiVectorSequenceStore, AsciiVectorSequenceStoreHandle,
+};
+use compact_genome::implementation::two_bit_vec_sequence_store::{
+    TwoBitVectorSequenceStore, TwoBitVectorSequenceStoreHandle,
+};
 use compact_genome::interface::sequence::{GenomeSequence, OwnedGenomeSequence};
 use compact_genome::interface::sequence_store::SequenceStore;
 
@@ -36,28 +40,46 @@ pub trait SequenceData<GenomeSequenceStore: SequenceStore> {
 
 impl SequenceData<TwoBitVectorSequenceStore> for TwoBitVectorSequenceStoreHandle {
     fn sequence_handle(&self) -> &<TwoBitVectorSequenceStore as SequenceStore>::Handle {
-        &self
+        self
     }
 
-    fn sequence_ref<'a>(&self, source_sequence_store: &'a TwoBitVectorSequenceStore) -> Option<&'a <TwoBitVectorSequenceStore as SequenceStore>::SequenceRef> {
+    fn sequence_ref<'a>(
+        &self,
+        source_sequence_store: &'a TwoBitVectorSequenceStore,
+    ) -> Option<&'a <TwoBitVectorSequenceStore as SequenceStore>::SequenceRef> {
         Some(source_sequence_store.get(self))
     }
 
-    fn sequence_owned<ResultSequence: for<'a> OwnedGenomeSequence<'a, ResultSubsequence>, ResultSubsequence: for<'a> GenomeSequence<'a, ResultSubsequence> + ?Sized>(&self, source_sequence_store: &TwoBitVectorSequenceStore) -> ResultSequence {
+    fn sequence_owned<
+        ResultSequence: for<'a> OwnedGenomeSequence<'a, ResultSubsequence>,
+        ResultSubsequence: for<'a> GenomeSequence<'a, ResultSubsequence> + ?Sized,
+    >(
+        &self,
+        source_sequence_store: &TwoBitVectorSequenceStore,
+    ) -> ResultSequence {
         source_sequence_store.get(self).convert()
     }
 }
 
 impl SequenceData<AsciiVectorSequenceStore> for AsciiVectorSequenceStoreHandle {
     fn sequence_handle(&self) -> &<AsciiVectorSequenceStore as SequenceStore>::Handle {
-        &self
+        self
     }
 
-    fn sequence_ref<'a>(&self, source_sequence_store: &'a AsciiVectorSequenceStore) -> Option<&'a <AsciiVectorSequenceStore as SequenceStore>::SequenceRef> {
+    fn sequence_ref<'a>(
+        &self,
+        source_sequence_store: &'a AsciiVectorSequenceStore,
+    ) -> Option<&'a <AsciiVectorSequenceStore as SequenceStore>::SequenceRef> {
         Some(source_sequence_store.get(self))
     }
 
-    fn sequence_owned<ResultSequence: for<'a> OwnedGenomeSequence<'a, ResultSubsequence>, ResultSubsequence: for<'a> GenomeSequence<'a, ResultSubsequence> + ?Sized>(&self, source_sequence_store: &AsciiVectorSequenceStore) -> ResultSequence {
+    fn sequence_owned<
+        ResultSequence: for<'a> OwnedGenomeSequence<'a, ResultSubsequence>,
+        ResultSubsequence: for<'a> GenomeSequence<'a, ResultSubsequence> + ?Sized,
+    >(
+        &self,
+        source_sequence_store: &AsciiVectorSequenceStore,
+    ) -> ResultSequence {
         source_sequence_store.get(self).convert()
     }
-}
\ No newline at end of file
+}
